# -*- coding: utf-8 -*-


class User:
  def __init__(self, **kwargs):
    self.messages = []
    if not 'name' in kwargs:
      raise ValueError('A name must be specified')
    self.name = kwargs['name']



# -*- coding: utf-8 -*-

"""
RWCI.py
~~~~~~~~~~~~~~~~~~~
An API wrapper for RWCI.

"""

from .client import Client
from .errors import BadLoginCredentials, BadEventListener
from .message import Message
from .user import User

__title__ = 'rwci'
__author__ = 'heyitswither'
__license__ = 'MIT'
__copyright__ = 'Copyright 2017-Present heyitswither'
__version__ = '0.1.5a0'



from setuptools import setup
import re, os

version = ''
with open('rwci/__init__.py') as f:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]', f.read(), re.MULTILINE).group(1)

if not version:
    raise RuntimeError('version is not set')

setup(name='rwci.py',
      author='heyitswither',
      author_email="tucker@boniface.tech",
      url='https://github.com/heyitswither/rwci.py',
      version=version,
      packages=['rwci'],
      license='MIT',
      description='A python wrapper for RWCI API.',
      include_package_data=True,
      install_requires=['websockets'],
      classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: MIT License',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Topic :: Internet',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities',
      ]
)
